@@ -1,18 +1,18 @@
 ###############################################################################
-# 
+#
 # configglue -- glue for your apps' configuration
-# 
+#
 # A library for simple, DRY configuration of applications
-# 
+#
 # (C) 2009--2010 by Canonical Ltd.
 # originally by John R. Lenton <john.lenton@canonical.com>
 # incorporating schemaconfig as configglue.pyschema
 # schemaconfig originally by Ricardo Kirkner <ricardo.kirkner@canonical.com>
-# 
+#
 # Released under the BSD License (see the file LICENSE)
-# 
+#
 # For bug reports, support, and new releases: http://launchpad.net/configglue
-# 
+#
 ###############################################################################
 
 """configglue lives here
@@ -27,12 +27,12 @@ from configglue.inischema.attributed import AttributedConfigParser
 from configglue.pyschema.glue import schemaconfigglue
 from configglue.pyschema.parser import SchemaConfigParser
 from configglue.pyschema.schema import (
-    BoolConfigOption,
-    ConfigSection,
-    IntConfigOption,
-    LinesConfigOption,
+    BoolOption,
+    Section,
+    IntOption,
+    ListOption,
     Schema,
-    StringConfigOption,
+    StringOption,
 )
 
 
@@ -58,10 +58,10 @@ def ini2schema(fd, p=None):
     p.readfp(fd)
     p.parse_all()
 
-    parser2option = {'unicode': StringConfigOption,
-                     'int': IntConfigOption,
-                     'bool': BoolConfigOption,
-                     'lines': LinesConfigOption}
+    parser2option = {'unicode': StringOption,
+                     'int': IntOption,
+                     'bool': BoolOption,
+                     'lines': ListOption}
 
     class MySchema(Schema):
         pass
@@ -70,7 +70,7 @@ def ini2schema(fd, p=None):
         if section_name == '__main__':
             section = MySchema
         else:
-            section = ConfigSection(name=section_name)
+            section = Section(name=section_name)
             setattr(MySchema, section_name, section)
         for option_name in p.options(section_name):
             option = p.get(section_name, option_name)
@@ -93,9 +93,9 @@ def ini2schema(fd, p=None):
             if option_action is not None:
                 attrs['action'] = option_action
 
-            klass = parser2option.get(parser, StringConfigOption)
+            klass = parser2option.get(parser, StringOption)
             if parser == 'lines':
-                instance = klass(item=StringConfigOption(), **attrs)
+                instance = klass(item=StringOption(), **attrs)
             else:
                 instance = klass(**attrs)
             setattr(section, option_name, instance)
